@@ -2,8 +2,8 @@
 ###################################################
 # improper density which is constant to 1
 dimproper <- function(x){
-	N <- base::length(x)
-	dx <- base::rep(1,N)
-	base::return(dx)
+	N <- length(x)
+	dx <- rep(1,N)
+	return(dx)
 }
-###################################################
\ No newline at end of file
+###################################################
