@@ -3,7 +3,7 @@
 # coefficients from one MCMC chain
 mcmc_coef <- function( mcmcobj , exclude="deviance" ){	
 	mcmcobj <- mcmcobj[ , ! ( colnames(mcmcobj) %in% exclude ) ]
-	res <- base::colMeans(mcmcobj)	
+	res <- colMeans(mcmcobj)	
 	colnames(mcmcobj) -> names(res)
-	base::return(res)
-		}
\ No newline at end of file
+	return(res)
+		}
