@@ -1,11 +1,12 @@
 
 #################################################################
-# Hierrachical rater model
+# Hierarchical rater model
 # MML estimation
-# 2014-10-06: renamed rm.hrm into rm.sdt
 rm.sdt <- function( dat , pid , rater ,Qmatrix=NULL , theta.k=seq(-9,9,len=30) , 	
 	est.a.item=FALSE , est.c.rater= "n" , 
-	est.d.rater= "n" , est.mean = FALSE , d.min=.5 , d.max=100 ,  d.start = 3 , 
+	est.d.rater= "n" , est.mean = FALSE , skillspace="normal" , 
+	tau.item.fixed = NULL , a.item.fixed = NULL , 
+	d.min=.5 , d.max=100 ,  d.start = 3 , 
 	max.increment=1 , numdiff.parm=.00001 , maxdevchange=.10 ,
 	globconv=.001 , maxiter=1000 , msteps=4 , mstepconv=.001){
 	#..........................................................
@@ -36,31 +37,59 @@ rm.sdt <- function( dat , pid , rater ,Qmatrix=NULL , theta.k=seq(-9,9,len=30) ,
 	
 	# define constraints on tau.item parameters
 	# if not all categories are observed
-	tau.item.fixed <- NULL
-	if ( min(maxK) < K ){
-		for (vv in 1:VV){
-		#vv <- 1
-			K.vv <- maxK[vv]
-			if ( K.vv < K ){
-				for (zz in (K.vv+1):K ){
-					d1 <- data.frame( "item"= vv, 
-							"categ"=zz , "val"=99 )	
-					tau.item.fixed <- rbind( tau.item.fixed , d1 ) 				
-									}
-							}
+#	tau.item.fixed <- NULL
+	if ( is.null( tau.item.fixed )){
+		if ( min(maxK) < K ){
+			for (vv in 1:VV){
+			#vv <- 1
+				K.vv <- maxK[vv]
+				if ( K.vv < K ){
+					for (zz in (K.vv+1):K ){
+						d1 <- data.frame( "item"= vv, "categ"=zz , "val"=99 )	
+						tau.item.fixed <- rbind( tau.item.fixed , d1 ) 				
+										}
+								}
+						}
+			tau.item.fixed <- as.matrix(tau.item.fixed )
 					}
-		tau.item.fixed <- as.matrix(tau.item.fixed )
 				}
+				
 	# starting values for item difficulties
 	tau.item <- matrix( 0 , nrow=VV , ncol=K )
 	rownames(tau.item) <- colnames(dat)
-	tau.item <- matrix( seq( -2 , 2 , len=K ) , nrow=VV , ncol=K , byrow=T )
+	
+	tau.item <- matrix( seq( -2 , 2 , len=K ) , nrow=VV , ncol=K , byrow=TRUE )
+	if ( ! is.null(tau.item.fixed) ){
+	    tau.item[ tau.item.fixed[,1:2,drop=FALSE] ] <- tau.item.fixed[,3]
+									}
+		
 	a.item <- rep( 1 , VV )
+	if (skillspace == "discrete" ){
+			est.mean <- TRUE
+						}
+	if ( ! is.null( a.item.fixed ) ){
+		est.a.item <- TRUE
+		a.item[ a.item.fixed[,1] ] <- a.item.fixed[,2]
+									}
 	
 	# rater parameter
 	d.rater <- matrix( d.start , nrow=I , ncol=1 )
-	c.rater <- matrix( d.start*((1:K) - .5 ) , nrow=I , ncol=K , byrow=T )
+	c.rater <- matrix( d.start*((1:K) - .5 ) , nrow=I , ncol=K , byrow=TRUE )
 	
+	# set c.rater for fixed items to 99
+	c.rater.fixed <- NULL
+	if ( ! is.null( tau.item.fixed ) ){
+		tau1 <- tau.item.fixed[ tau.item.fixed[,3] == 99 , , drop=FALSE]		
+		ind <- match( item.index , tau1[,1] )
+		c.rater.fixed <- tau1[ ind , ]
+        c.rater.fixed[,1] <- seq( 1 , nrow(c.rater.fixed) )	
+#		c.rater.fixed[,3] <- - 99
+		c.rater.fixed[,3] <- 999
+		c.rater.fixed <- c.rater.fixed[ ! is.na( c.rater.fixed[,2] ) , ] 
+		c.rater[ c.rater.fixed[,1:2] ] <- c.rater.fixed[,3]
+		
+							}
+		
     # init standard errors
 	se.d.rater <- NA*d.rater
 	se.c.rater <- NA*c.rater
@@ -90,7 +119,7 @@ rm.sdt <- function( dat , pid , rater ,Qmatrix=NULL , theta.k=seq(-9,9,len=30) ,
 		a.item0 <- a.item
 		c.rater0 <- c.rater
 
-#  a0 <- Sys.time()		
+  a0 <- Sys.time()		
 		# calculate probabilities
 		res <- .rm.hrm.calcprobs( c.rater , Qmatrix , tau.item ,
 				VV , K , I , TP , a.item , d.rater , item.index , rater.index ,
@@ -111,7 +140,7 @@ rm.sdt <- function( dat , pid , rater ,Qmatrix=NULL , theta.k=seq(-9,9,len=30) ,
 		ll <- res$ll
 
 # cat("posterior "); a1 <- Sys.time(); print(a1-a0) ; a0 <- a1 ;			
-												
+																					
     	# estimate tau.item parameters
 		if (iter ==0){	max.b.increment -> tau.item.incr }
 		res <- .rm.hrm.est.tau.item( c.rater , Qmatrix , tau.item ,
@@ -124,7 +153,7 @@ rm.sdt <- function( dat , pid , rater ,Qmatrix=NULL , theta.k=seq(-9,9,len=30) ,
 		tau.item.incr <- ifelse( tau.item.incr > g1 , g1 , tau.item.incr )						
 		prob.item <- res$prob.item
 # cat("est.tau "); a1 <- Sys.time(); print(a1-a0) ; a0 <- a1 ;			
-		
+
 		
 		# estimate a.item parameter
 		if (est.a.item){
@@ -132,7 +161,7 @@ rm.sdt <- function( dat , pid , rater ,Qmatrix=NULL , theta.k=seq(-9,9,len=30) ,
 			res <- .rm.hrm.est.a.item( c.rater , Qmatrix , tau.item ,
 				VV , K , I , TP , a.item , d.rater , item.index , rater.index ,
 				n.ik , numdiff.parm , max.b.increment=a.item.incr ,theta.k ,
-				msteps, mstepconv , prob.rater  )		
+				msteps, mstepconv , prob.rater  , a.item.fixed )		
 			a.item <- res$a.item
 			se.a.item <- res$se.a.item
 			a.item.incr <- abs( a.item0 - a.item )
@@ -144,7 +173,7 @@ rm.sdt <- function( dat , pid , rater ,Qmatrix=NULL , theta.k=seq(-9,9,len=30) ,
 				
 		# estimate d.rater parameter
 		if (est.d.rater!="n"){
-			if (iter ==0){	2 -> d.rater.incr }	
+			if (iter ==0){	d.rater.incr <- 2 }	
 			res <- .rm.hrm.est.d.rater(  c.rater , Qmatrix , tau.item ,
 					VV , K , I , TP , a.item , d.rater , item.index , rater.index ,
 					n.ik , numdiff.parm, max.b.increment=d.rater.incr,theta.k ,
@@ -164,21 +193,20 @@ rm.sdt <- function( dat , pid , rater ,Qmatrix=NULL , theta.k=seq(-9,9,len=30) ,
 			res <- .rm.hrm.est.c.rater(  c.rater , Qmatrix , tau.item ,
 					VV , K , I , TP , a.item , d.rater , item.index , rater.index ,
 					n.ik , numdiff.parm, max.b.increment=c.rater.incr,theta.k ,
-					msteps , mstepconv , est.c.rater , prob.item )
+					msteps , mstepconv , est.c.rater , prob.item , c.rater.fixed)
 			c.rater <- res$c.rater
 			se.c.rater <- res$se.c.rater
 			g1 <- abs( c.rater0 - c.rater )
 			c.rater.incr <- max(g1)
 #			c.rater.incr <- ifelse( c.rater.incr > g1 , g1 , c.rater.incr )						
 						}						
-# cat("est.c.rater "); a1 <- Sys.time(); print(a1-a0) ; a0 <- a1 ;			
+ #cat("est.c.rater "); a1 <- Sys.time(); print(a1-a0) ; a0 <- a1 ;			
 						
 		flush.console()		
 		
-#stop("here")		
 		
 		# update distribution
-		res <- rm.smooth.distribution( theta.k , pi.k , est.mean = est.mean )
+		res <- rm.smooth.distribution( theta.k , pi.k , est.mean = est.mean , skillspace)
 		pi.k <- res$pi.k
 		mu <- res$mu
 		sigma <- res$sigma
@@ -210,22 +238,61 @@ rm.sdt <- function( dat , pid , rater ,Qmatrix=NULL , theta.k=seq(-9,9,len=30) ,
 				
 	# *********
 	# arrange OUTPUT
+	
+	# c parameters
+	if ( ! is.null( c.rater.fixed ) ){
+		c.rater[ c.rater.fixed[,1:2] ] <- NA
+						}
+	
 	#---
 	# Information criteria
 	ic <- list( "deviance" = dev , "n" = nrow(dat2) )
 	ic$VV <- VV
 	ic$RR <- RR
-	ic$np.item <- sum( maxK) + est.a.item*(VV-1)
+	#****
+	# skill parameters
+	ic$np.skill <- 0
+	if ( skillspace == "normal" ){
+		ic$np.skill <- 1 + est.mean
+						}
+	if ( skillspace == "discrete" ){
+		ic$np.skill <- length(theta.k) - 1
+						}	
+	#*****
+	# item parameters
+	ic$np.item <- VV * max( maxK )
+	if ( ! is.null(tau.item.fixed)){
+			ic$np.item <- ic$np.item - nrow(tau.item.fixed)
+									}
+	if ( is.null( a.item.fixed ) ){ 
+		ic$np.item <- ic$np.item + est.a.item*(VV-1)
+						} else {
+		ic$np.item <- ic$np.item + VV - 1
+						}
+						
+	#*****
+	# rater parameters
 	ic$np.rater <- 0
 	if ( est.d.rater=="e" ){ ic$np.rater <- ic$np.rater + 1 }
 	if ( est.d.rater=="i" ){ ic$np.rater <- ic$np.rater + VV }	
 	if ( est.d.rater=="r" ){ ic$np.rater <- ic$np.rater + RR }	
 	if ( est.d.rater=="a" ){ ic$np.rater <- ic$np.rater + I }		
-	if ( est.c.rater=="e" ){ ic$np.rater <- ic$np.rater + K }
-	if ( est.c.rater=="i" ){ ic$np.rater <- ic$np.rater + K*VV }	
-	if ( est.c.rater=="r" ){ ic$np.rater <- ic$np.rater + K*RR }		
-	if ( est.c.rater=="a" ){ ic$np.rater <- ic$np.rater + K*I }			
-	ic$np <- 1 + ic$np.item + ic$np.rater
+	if ( est.c.rater=="e" ){ 
+			ic$np.rater <- ic$np.rater + K 
+						}
+	if ( est.c.rater=="i" ){ 
+			ic$np.rater <- ic$np.rater + sum(maxK)
+							}	
+	if ( est.c.rater=="r" ){ 
+			ic$np.rater <- ic$np.rater + K*RR 
+							}		
+	if ( est.c.rater=="a" ){ 
+			ic$np.rater <- ic$np.rater + K*I 
+		if ( ! is.null( c.rater.fixed ) ){
+			ic$np.rater <- ic$np.rater - nrow( c.rater.fixed )
+						}			
+						}		
+	ic$np <- ic$np.skill + ic$np.item + ic$np.rater
     # AIC
     ic$AIC <- dev + 2*ic$np
     # BIC
@@ -249,13 +316,25 @@ rm.sdt <- function( dat , pid , rater ,Qmatrix=NULL , theta.k=seq(-9,9,len=30) ,
 				( mean( person$SE.EAP^2 ) + var( person$EAP ) )
 
 	
+	
 	#---
 	# item
 	if (!is.null(tau.item.fixed)){
-		tau.item[ tau.item.fixed[,1:2,drop=FALSE] ] <- NA
-		se.tau.item[ tau.item.fixed[,1:2,drop=FALSE] ] <- NA		
+#		 tau.item[ tau.item.fixed[,1:2,drop=FALSE] ] <- NA
+#        tau.item[ tau.item.fixed1[,1:2,drop=FALSE] ] <- NA	
+		K <- max(maxK)
+        I <- nrow(tau.item)
+		for (ii in 1:I){
+		  if ( maxK[ii] < K ){
+			for (kk in seq(maxK[ii]+1,K) ){
+				tau.item[ii,kk] <- NA
+										}
+								}
 							}
-	
+		se.tau.item[ tau.item.fixed[,1:2,drop=FALSE] ] <- NA								
+							}
+
+							
     item <- data.frame( "item" = colnames(dat) , 
 			"N" = colSums( 1-is.na(dat)) , 
 			"M" = colMeans( dat , na.rm=T ) )
@@ -298,15 +377,37 @@ rm.sdt <- function( dat , pid , rater ,Qmatrix=NULL , theta.k=seq(-9,9,len=30) ,
 		rater[ , paste0("c_",zz)] <- c.rater[,zz] }
 	# transformed c parameters
     for (zz in 1:(ncol(c.rater) ) ){
-#		rater[ , paste0("c_",zz,".trans")] <- c.rater[,zz] / d.rater[zz] / K 
-		rater[ , paste0("c_",zz,".trans")] <- c.rater[,zz] / d.rater / K 
+		# rater[ , paste0("c_",zz,".trans")] <- c.rater[,zz] / d.rater / K 
+        rater[ , paste0("c_",zz,".trans")] <- c.rater[,zz] / d.rater	
 			}
-			
+
+
+	rater <- rater[ order( paste( rater$item.rater) ) , ]
+	rownames(rater) <- NULL
+	rownames(item) <- NULL
+
+	rt1 <- rater
+	l1 <- paste(rt1$item.rater)
+	l2 <- strsplit( l1 , split="-" )
+	rt1$item <- unlist( lapply( l2 , FUN = function(uu){ uu[[1]] } ) )
+	rt1$rater <- unlist( lapply( l2 , FUN = function(uu){ uu[[2]] } ) )
+	
 	#*****
 	# dimnames probs
 	dimnames(probs)[[1]] <- colnames(dat2)
 	#*****			
 						
+	#*****
+	# distribution	
+	skill.distribution <- data.frame("theta.k" = theta.k , "pi.k" = pi.k )
+	
+	#*****
+	# labels
+	dimnames(prob.item) <- list( colnames(dat) , paste0("Cat" , 0:K) , NULL )
+	dimnames(prob.rater) <- list( colnames(dat2) , paste0("Cat" , 0:K) , NULL )	
+
+	
+						
 	obji <- rater
 	for (vv in seq(2,ncol(obji) )){
 		obji[,vv] <- round( obji[,vv],3 ) }
@@ -318,6 +419,7 @@ rm.sdt <- function( dat , pid , rater ,Qmatrix=NULL , theta.k=seq(-9,9,len=30) ,
 	
 	s2 <- Sys.time()
 
+	
 
     res <- list("deviance" = dev , "ic"=ic , "item"=item , "rater"=rater ,
 		"person" = person , "EAP.rel"=EAP.rel , 
@@ -332,7 +434,9 @@ rm.sdt <- function( dat , pid , rater ,Qmatrix=NULL , theta.k=seq(-9,9,len=30) ,
 		"n.ik"=n.ik , "maxK"=maxK , "pi.k" = pi.k ,
 		"procdata" =procdata , "iter"=iter , "theta.k" = theta.k , 
 		"Qmatrix" = Qmatrix , 
-		"s1"=s1 , "s2"=s2 , "tau.item.fixed"=tau.item.fixed)
+		"s1"=s1 , "s2"=s2 , "tau.item.fixed"=tau.item.fixed ,
+		"rater2" = rt1 , "maxK" = maxK , "skill.distribution"=skill.distribution ,
+		"skillspace" = skillspace )
 	class(res) <- "rm.sdt"
 	return(res)
 
