@@ -3,9 +3,9 @@
 
 xxirt_partable_include_freeParameters <- function( partable , x ){
 		vals <- x[ partable$parindex ]
-		ind <- base::is.na(vals)
+		ind <- is.na(vals)
 		vals[ ind ] <- partable$value[ ind ]
 		partable$value <- vals
-		base::return(partable)
+		return(partable)
 }
-		
\ No newline at end of file
+		
